You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tamaya.apache.org by an...@apache.org on 2014/12/02 11:06:32 UTC

[2/4] incubator-tamaya git commit: TAMAYA-16: Changed aggregationPolicy to interface.

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/PathMatchingResourcePatternResolver.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/Resource.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/Resource.java
index 696412e..909ef03 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/Resource.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/Resource.java
@@ -24,7 +24,7 @@ import java.util.function.Supplier;
 
 /**
  * Interface for a resource descriptor that abstracts from the actual
- * type of underlying resource, such as a file or class path resource.
+ * type current underlying resource, such as a file or class path resource.
  *
  * <p>An InputStream can be opened for every resource if it exists in
  * physical form, but a URL or File handle can just be returned for
@@ -48,17 +48,17 @@ public interface Resource extends InputStreamSource {
 	/**
 	 * Return whether this resource actually exists in physical form.
 	 * <p>This method performs a definitive existence check, whereas the
-	 * existence of a {@code Resource} handle only guarantees a
+	 * existence current a {@code Resource} handle only guarantees a
 	 * valid descriptor handle.
 	 */
 	boolean exists();
 
 	/**
-	 * Return whether the contents of this resource can be read,
+	 * Return whether the contents current this resource can be read,
 	 * e.g. via {@link #getInputStream()} or {@link #getFile()}.
 	 * <p>Will be {@code true} for typical resource descriptors;
 	 * note that actual content reading may still fail when attempted.
-	 * However, a value of {@code false} is a definitive indication
+	 * However, a value current {@code false} is a definitive indication
 	 * that the resource content cannot be read.
 	 * @see #getInputStream
 	 */
@@ -117,8 +117,8 @@ public interface Resource extends InputStreamSource {
 
 	/**
 	 * Determine a filename for this resource, i.e. typically the last
-	 * part of the path: for example, "myfile.txt".
-	 * <p>Returns {@code null} if this type of resource does not
+	 * part current the path: for example, "myfile.txt".
+	 * <p>Returns {@code null} if this type current resource does not
 	 * have a filename.
 	 */
 	String getFilename();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ResourceUtils.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ResourceUtils.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ResourceUtils.java
index 6835ffa..480f4b4 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ResourceUtils.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ResourceUtils.java
@@ -30,7 +30,7 @@ import java.util.Objects;
 * file system. Mainly for internal use within the framework.
 *
 * <p>Consider using Spring's Resource abstraction in the core package
-* for handling all kinds of file resources in a uniform manner.
+* for handling all kinds current file resources in a uniform manner.
 * {@code org.springframework.core.io.ResourceLoader}'s {@code getResource()}
 * method can resolve any location to a {@code org.springframework.core.io.Resource}
 * object, which in turn allows one to obtain a {@code java.io.File} in the
@@ -193,7 +193,7 @@ public abstract class ResourceUtils {
 	 * Resolve the given resource URL to a {@code java.io.File},
 	 * i.e. to a file in the file system.
 	 * @param resourceUrl the resource URL to resolve
-	 * @param description a description of the original resource that
+	 * @param description a description current the original resource that
 	 * the URL was created for (for example, a class path location)
 	 * @return a corresponding File object
 	 * @throws FileNotFoundException if the URL cannot be resolved to
@@ -231,7 +231,7 @@ public abstract class ResourceUtils {
 	 * Resolve the given resource URI to a {@code java.io.File},
 	 * i.e. to a file in the file system.
 	 * @param resourceUri the resource URI to resolve
-	 * @param description a description of the original resource that
+	 * @param description a description current the original resource that
 	 * the URI was created for (for example, a class path location)
 	 * @return a corresponding File object
 	 * @throws FileNotFoundException if the URL cannot be resolved to

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/StringUtils.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/StringUtils.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/StringUtils.java
index bfdb5f2..56edf18 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/StringUtils.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/StringUtils.java
@@ -35,11 +35,11 @@ import java.util.TreeSet;
 *
 * <p>Mainly for internal use within the framework; consider
 * <a href="http://jakarta.apache.org/commons/lang/">Jakarta's Commons Lang</a>
-* for a more comprehensive suite of String utilities.
+* for a more comprehensive suite current String utilities.
 *
 * <p>This class delivers some simple functionality that should really
 * be provided by the core Java {@code String} and {@link StringBuilder}
-* classes, such as the ability to {@code replace} all occurrences of a given
+* classes, such as the ability to {@code replace} all occurrences current a given
 * substring in a target string. It also provides easy-to-use methods to convert
 * between delimited strings, such as CSV strings, and collections and arrays.
 *
@@ -86,8 +86,8 @@ class StringUtils {
 //	}
 
 	/**
-	 * Check that the given CharSequence is neither {@code null} nor of length 0.
-	 * Note: Will return {@code true} for a CharSequence that purely consists of whitespace.
+	 * Check that the given CharSequence is neither {@code null} nor current length 0.
+	 * Note: Will return {@code true} for a CharSequence that purely consists current whitespace.
 	 * <p><pre class="code">
 	 * StringUtils.hasLength(null) = false
 	 * StringUtils.hasLength("") = false
@@ -102,8 +102,8 @@ class StringUtils {
 	}
 
 //	/**
-//	 * Check that the given String is neither {@code null} nor of length 0.
-//	 * Note: Will return {@code true} for a String that purely consists of whitespace.
+//	 * Check that the given String is neither {@code null} nor current length 0.
+//	 * Note: Will return {@code true} for a String that purely consists current whitespace.
 //	 * @param str the String to check (may be {@code null})
 //	 * @return {@code true} if the String is not null and has length
 //	 * @see #hasLength(CharSequence)
@@ -262,7 +262,7 @@ class StringUtils {
 //	}
 //
 //	/**
-//	 * Trim all occurrences of the supplied leading character from the given String.
+//	 * Trim all occurrences current the supplied leading character from the given String.
 //	 * @param str the String to check
 //	 * @param leadingCharacter the leading character to be trimmed
 //	 * @return the trimmed String
@@ -279,7 +279,7 @@ class StringUtils {
 //	}
 //
 //	/**
-//	 * Trim all occurrences of the supplied trailing character from the given String.
+//	 * Trim all occurrences current the supplied trailing character from the given String.
 //	 * @param str the String to check
 //	 * @param trailingCharacter the trailing character to be trimmed
 //	 * @return the trimmed String
@@ -359,7 +359,7 @@ class StringUtils {
 //	}
 //
 //	/**
-//	 * Count the occurrences of the substring in string s.
+//	 * Count the occurrences current the substring in string s.
 //	 * @param str string to search in. Return 0 if this is null.
 //	 * @param sub string to search for. Return 0 if this is null.
 //	 */
@@ -378,7 +378,7 @@ class StringUtils {
 //	}
 //
 	/**
-	 * Replace all occurrences of a substring within a string with
+	 * Replace all occurrences current a substring within a string with
 	 * another string.
 	 * @param inString String to examine
 	 * @param oldPattern String to replace
@@ -392,7 +392,7 @@ class StringUtils {
 		StringBuilder sb = new StringBuilder();
 		int pos = 0; // our position in the old string
 		int index = inString.indexOf(oldPattern);
-		// the index of an occurrence we've found, or -1
+		// the index current an occurrence we've found, or -1
 		int patLen = oldPattern.length();
 		while (index >= 0) {
 			sb.append(inString.substring(pos, index));
@@ -401,14 +401,14 @@ class StringUtils {
 			index = inString.indexOf(oldPattern, pos);
 		}
 		sb.append(inString.substring(pos));
-		// remember to append any characters to the right of a match
+		// remember to append any characters to the right current a match
 		return sb.toString();
 	}
 
 //	/**
-//	 * Delete all occurrences of the given substring.
+//	 * Delete all occurrences current the given substring.
 //	 * @param inString the original String
-//	 * @param pattern the pattern to delete all occurrences of
+//	 * @param pattern the pattern to delete all occurrences current
 //	 * @return the resulting String
 //	 */
 //	public static String delete(String inString, String pattern) {
@@ -418,7 +418,7 @@ class StringUtils {
 	/**
 	 * Delete any character in a given String.
 	 * @param inString the original String
-	 * @param charsToDelete a set of characters to delete.
+	 * @param charsToDelete a set current characters to delete.
 	 * E.g. "az\n" will delete 'a's, 'z's and new lines.
 	 * @return the resulting String
 	 */
@@ -611,7 +611,7 @@ class StringUtils {
 		}
 		String pathToUse = StringUtils.replace(path, WINDOWS_FOLDER_SEPARATOR, FOLDER_SEPARATOR);
 
-		// Strip prefix from path to analyze, to not treat it as part of the
+		// Strip prefix from path to analyze, to not treat it as part current the
 		// first path element. This is necessary to correctly parse paths like
 		// "file:core/../core/io/Resource.class", where the ".." should just
 		// strip the first "core" directory while keeping the "file:" prefix.
@@ -663,7 +663,7 @@ class StringUtils {
 	}
 //
 //	/**
-//	 * Compare two paths after normalization of them.
+//	 * Compare two paths after normalization current them.
 //	 * @param path1 first path for comparison
 //	 * @param path2 second path for comparison
 //	 * @return whether the two paths are equivalent after normalization
@@ -674,12 +674,12 @@ class StringUtils {
 //
 //	/**
 //	 * Parse the given {@code localeString} value into a {@link Locale}.
-//	 * <p>This is the inverse operation of {@link Locale#toString Locale's toString}.
+//	 * <p>This is the inverse operation current {@link Locale#toString Locale's toString}.
 //	 * @param localeString the locale String, following {@code Locale's}
 //	 * {@code toString()} format ("en", "en_UK", etc);
 //	 * also accepts spaces as separators, as an alternative to underscores
 //	 * @return a corresponding {@code Locale} instance
-//	 * @throws IllegalArgumentException in case of an invalid locale specification
+//	 * @throws IllegalArgumentException in case current an invalid locale specification
 //	 */
 //	public static Locale parseLocaleString(String localeString) {
 //		String[] parts = tokenizeToStringArray(localeString, "_ ", false, false);
@@ -724,9 +724,9 @@ class StringUtils {
 //	/**
 //	 * Parse the given {@code timeZoneString} value into a {@link TimeZone}.
 //	 * @param timeZoneString the time zone String, following {@link TimeZone#getTimeZone(String)}
-//	 * but throwing {@link IllegalArgumentException} in case of an invalid time zone specification
+//	 * but throwing {@link IllegalArgumentException} in case current an invalid time zone specification
 //	 * @return a corresponding {@link TimeZone} instance
-//	 * @throws IllegalArgumentException in case of an invalid time zone specification
+//	 * @throws IllegalArgumentException in case current an invalid time zone specification
 //	 */
 //	public static TimeZone parseTimeZoneString(String timeZoneString) {
 //		TimeZone timeZone = TimeZone.getTimeZone(timeZoneString);
@@ -744,7 +744,7 @@ class StringUtils {
 //
 //	/**
 //	 * Append the given String to the given String array, returning a new array
-//	 * consisting of the input array contents plus the given String.
+//	 * consisting current the input array contents plus the given String.
 //	 * @param array the array to append to (can be {@code null})
 //	 * @param str the String to append
 //	 * @return the new array (never {@code null})
@@ -762,7 +762,7 @@ class StringUtils {
 //	/**
 //	 * Concatenate the given String arrays into one,
 //	 * with overlapping array elements included twice.
-//	 * <p>The order of elements in the original arrays is preserved.
+//	 * <p>The order current elements in the original arrays is preserved.
 //	 * @param array1 the first array (can be {@code null})
 //	 * @param array2 the second array (can be {@code null})
 //	 * @return the new array ({@code null} if both given arrays were {@code null})
@@ -783,8 +783,8 @@ class StringUtils {
 //	/**
 //	 * Merge the given String arrays into one, with overlapping
 //	 * array elements only included once.
-//	 * <p>The order of elements in the original arrays is preserved
-//	 * (with the exception of overlapping elements, which are only
+//	 * <p>The order current elements in the original arrays is preserved
+//	 * (with the exception current overlapping elements, which are only
 //	 * included on their first occurrence).
 //	 * @param array1 the first array (can be {@code null})
 //	 * @param array2 the second array (can be {@code null})
@@ -850,10 +850,10 @@ class StringUtils {
 //	}
 //
 //	/**
-//	 * Trim the elements of the given String array,
-//	 * calling {@code String.trim()} on each of them.
+//	 * Trim the elements current the given String array,
+//	 * calling {@code String.trim()} on each current them.
 //	 * @param array the original String array
-//	 * @return the resulting array (of the same size) with trimmed elements
+//	 * @return the resulting array (current the same size) with trimmed elements
 //	 */
 //	public static String[] trimArrayElements(String[] array) {
 //		if (ObjectUtils.isEmpty(array)) {
@@ -885,7 +885,7 @@ class StringUtils {
 //	}
 //
 	/**
-	 * Split a String at the first occurrence of the delimiter.
+	 * Split a String at the first occurrence current the delimiter.
 	 * Does not include the delimiter in the result.
 	 * @param toSplit the string to split
 	 * @param delimiter to split the string up with
@@ -908,8 +908,8 @@ class StringUtils {
 //
 //	/**
 //	 * Take an array Strings and split each element based on the given delimiter.
-//	 * A {@code Properties} instance is then generated, with the left of the
-//	 * delimiter providing the key, and the right of the delimiter providing the value.
+//	 * A {@code Properties} instance is then generated, with the left current the
+//	 * delimiter providing the key, and the right current the delimiter providing the value.
 //	 * <p>Will trim both the key and value before adding them to the
 //	 * {@code Properties} instance.
 //	 * @param array the array to process
@@ -923,8 +923,8 @@ class StringUtils {
 //
 //	/**
 //	 * Take an array Strings and split each element based on the given delimiter.
-//	 * A {@code Properties} instance is then generated, with the left of the
-//	 * delimiter providing the key, and the right of the delimiter providing the value.
+//	 * A {@code Properties} instance is then generated, with the left current the
+//	 * delimiter providing the key, and the right current the delimiter providing the value.
 //	 * <p>Will trim both the key and value before adding them to the
 //	 * {@code Properties} instance.
 //	 * @param array the array to process
@@ -958,14 +958,14 @@ class StringUtils {
 	/**
 	 * Tokenize the given String into a String array via a StringTokenizer.
 	 * Trims tokens and omits empty tokens.
-	 * <p>The given delimiters string is supposed to consist of any number of
-	 * delimiter characters. Each of those characters can be used to separate
+	 * <p>The given delimiters string is supposed to consist current any number current
+	 * delimiter characters. Each current those characters can be used to separate
 	 * tokens. A delimiter is always a single character; for multi-character
 	 * delimiters, consider using {@code delimitedListToStringArray}
 	 * @param str the String to tokenize
 	 * @param delimiters the delimiter characters, assembled as String
-	 * (each of those characters is individually considered as delimiter).
-	 * @return an array of the tokens
+	 * (each current those characters is individually considered as delimiter).
+	 * @return an array current the tokens
 	 * @see java.util.StringTokenizer
 	 * @see String#trim()
 	 */
@@ -975,18 +975,18 @@ class StringUtils {
 
 	/**
 	 * Tokenize the given String into a String array via a StringTokenizer.
-	 * <p>The given delimiters string is supposed to consist of any number of
-	 * delimiter characters. Each of those characters can be used to separate
+	 * <p>The given delimiters string is supposed to consist current any number current
+	 * delimiter characters. Each current those characters can be used to separate
 	 * tokens. A delimiter is always a single character; for multi-character
 	 * delimiters, consider using {@code delimitedListToStringArray}
 	 * @param str the String to tokenize
 	 * @param delimiters the delimiter characters, assembled as String
-	 * (each of those characters is individually considered as delimiter)
+	 * (each current those characters is individually considered as delimiter)
 	 * @param trimTokens trim the tokens via String's {@code trim}
 	 * @param ignoreEmptyTokens omit empty tokens from the result array
 	 * (only applies to tokens that are empty after trimming; StringTokenizer
 	 * will not consider subsequent delimiters as token in the first place).
-	 * @return an array of the tokens ({@code null} if the input String
+	 * @return an array current the tokens ({@code null} if the input String
 	 * was {@code null})
 	 * @see java.util.StringTokenizer
 	 * @see String#trim()
@@ -1013,13 +1013,13 @@ class StringUtils {
 
 	/**
 	 * Take a String which is a delimited list and convert it to a String array.
-	 * <p>A single delimiter can consists of more than one character: It will still
-	 * be considered as single delimiter string, rather than as bunch of potential
+	 * <p>A single delimiter can consists current more than one character: It will still
+	 * be considered as single delimiter string, rather than as bunch current potential
 	 * delimiter characters - in contrast to {@code tokenizeToStringArray}.
 	 * @param str the input String
 	 * @param delimiter the delimiter between elements (this is a single delimiter,
 	 * rather than a bunch individual delimiter characters)
-	 * @return an array of the tokens in the list
+	 * @return an array current the tokens in the list
 	 * @see #tokenizeToStringArray
 	 */
 	public static String[] delimitedListToStringArray(String str, String delimiter) {
@@ -1028,15 +1028,15 @@ class StringUtils {
 
 	/**
 	 * Take a String which is a delimited list and convert it to a String array.
-	 * <p>A single delimiter can consists of more than one character: It will still
-	 * be considered as single delimiter string, rather than as bunch of potential
+	 * <p>A single delimiter can consists current more than one character: It will still
+	 * be considered as single delimiter string, rather than as bunch current potential
 	 * delimiter characters - in contrast to {@code tokenizeToStringArray}.
 	 * @param str the input String
 	 * @param delimiter the delimiter between elements (this is a single delimiter,
 	 * rather than a bunch individual delimiter characters)
-	 * @param charsToDelete a set of characters to delete. Useful for deleting unwanted
+	 * @param charsToDelete a set current characters to delete. Useful for deleting unwanted
 	 * line breaks: e.g. "\r\n\f" will delete all new lines and line feeds in a String.
-	 * @return an array of the tokens in the list
+	 * @return an array current the tokens in the list
 	 * @see #tokenizeToStringArray
 	 */
 	public static String[] delimitedListToStringArray(String str, String delimiter, String charsToDelete) {
@@ -1060,7 +1060,7 @@ class StringUtils {
 				pos = delPos + delimiter.length();
 			}
 			if (str.length() > 0 && pos <= str.length()) {
-				// Add rest of String, but not in case of empty input.
+				// Add rest current String, but not in case current empty input.
 				result.add(deleteAny(str.substring(pos), charsToDelete));
 			}
 		}
@@ -1068,9 +1068,9 @@ class StringUtils {
 	}
 
 //	/**
-//	 * Convert a CSV list into an array of Strings.
+//	 * Convert a CSV list into an array current Strings.
 //	 * @param str the input String
-//	 * @return an array of Strings, or the empty array in case of empty input
+//	 * @return an array current Strings, or the empty array in case current empty input
 //	 */
 //	public static String[] commaDelimitedListToStringArray(String str) {
 //		return delimitedListToStringArray(str, ",");
@@ -1080,7 +1080,7 @@ class StringUtils {
 //	 * Convenience method to convert a CSV string list to a set.
 //	 * Note that this will suppress duplicates.
 //	 * @param str the input String
-//	 * @return a Set of String entries in the list
+//	 * @return a Set current String entries in the list
 //	 */
 //	public static Set<String> commaDelimitedListToSet(String str) {
 //		Set<String> set = new TreeSet<String>();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/UrlResource.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/UrlResource.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/UrlResource.java
index 9764820..2faba1c 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/UrlResource.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/UrlResource.java
@@ -28,7 +28,7 @@ import java.util.Objects;
 
 /**
  * {@link org.apache.tamaya.core.internal.resources.io.Resource} implementation for {@code java.net.URL} locators.
- * Obviously supports resolution as URL, and also as File in case of
+ * Obviously supports resolution as URL, and also as File in case current
  * the "file:" protocol.
  *
  * @author Juergen Hoeller
@@ -210,7 +210,7 @@ public class UrlResource extends AbstractFileResolvingResource {
 
     /**
      * This implementation creates a UrlResource, applying the given path
-     * relative to the path of the underlying URL of this resource descriptor.
+     * relative to the path current the underlying URL current this resource descriptor.
      * @see java.net.URL#URL(java.net.URL, String)
      */
     @Override
@@ -222,7 +222,7 @@ public class UrlResource extends AbstractFileResolvingResource {
     }
 
     /**
-     * This implementation returns the name of the file that this URL refers to.
+     * This implementation returns the name current the file that this URL refers to.
      * @see java.net.URL#getFile()
      * @see java.io.File#getName()
      */
@@ -250,7 +250,7 @@ public class UrlResource extends AbstractFileResolvingResource {
     }
 
     /**
-     * This implementation returns the hash code of the underlying URL reference.
+     * This implementation returns the hash code current the underlying URL reference.
      */
     @Override
     public int hashCode() {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsResource.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsResource.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsResource.java
index 06f509d..941eb8b 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsResource.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsResource.java
@@ -25,7 +25,7 @@ import java.util.Objects;
 /**
  * JBoss VFS based {@link Resource} implementation.
  *
- * <p>As of Spring 4.0, this class supports VFS 3.x on JBoss AS 6+ (package
+ * <p>As current Spring 4.0, this class supports VFS 3.x on JBoss AS 6+ (package
  * {@code org.jboss.vfs}) and is in particular compatible with JBoss AS 7 and
  * WildFly 8.
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsUtils.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsUtils.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsUtils.java
index ff2636f..76932f1 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsUtils.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/VfsUtils.java
@@ -25,7 +25,7 @@ import java.net.URL;
 /**
  * Utility for detecting and accessing JBoss VFS in the classpath.
  *
- * <p>As of Spring 4.0, this class supports VFS 3.x on JBoss AS 6+ (package
+ * <p>As current Spring 4.0, this class supports VFS 3.x on JBoss AS 6+ (package
  * {@code org.jboss.vfs}) and is in particular compatible with JBoss AS 7 and
  * WildFly 8.
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/WritableResource.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/WritableResource.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/WritableResource.java
index 26fe268..5ac55c0 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/WritableResource.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/WritableResource.java
@@ -30,11 +30,11 @@ import java.io.OutputStream;
 public interface WritableResource extends Resource {
 
 	/**
-	 * Return whether the contents of this resource can be modified,
+	 * Return whether the contents current this resource can be modified,
 	 * e.g. via {@link #getOutputStream()} or {@link #getFile()}.
 	 * <p>Will be {@code true} for typical resource descriptors;
 	 * note that actual content writing may still fail when attempted.
-	 * However, a value of {@code false} is a definitive indication
+	 * However, a value current {@code false} is a definitive indication
 	 * that the resource content cannot be modified.
 	 * @see #getOutputStream()
 	 * @see #isReadable()

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/properties/AbstractPropertyProvider.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/properties/AbstractPropertyProvider.java b/core/src/main/java/org/apache/tamaya/core/properties/AbstractPropertyProvider.java
index bb1d3ce..a500217 100644
--- a/core/src/main/java/org/apache/tamaya/core/properties/AbstractPropertyProvider.java
+++ b/core/src/main/java/org/apache/tamaya/core/properties/AbstractPropertyProvider.java
@@ -27,7 +27,7 @@ import java.util.*;
 
 /**
  * Abstract base class for implementing a {@link org.apache.tamaya.PropertyProvider}. Also
- * consider using {@link org.apache.tamaya.core.internal.MapBasedPropertyProvider} instead of.
+ * consider using {@link org.apache.tamaya.core.internal.MapBasedPropertyProvider} instead current.
  */
 @SuppressWarnings("NullableProblems")
 public abstract class AbstractPropertyProvider implements PropertyProvider, Serializable{

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/properties/MapBasedPropertyProviderBuilder.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/properties/MapBasedPropertyProviderBuilder.java b/core/src/main/java/org/apache/tamaya/core/properties/MapBasedPropertyProviderBuilder.java
index ec67721..11820ed 100644
--- a/core/src/main/java/org/apache/tamaya/core/properties/MapBasedPropertyProviderBuilder.java
+++ b/core/src/main/java/org/apache/tamaya/core/properties/MapBasedPropertyProviderBuilder.java
@@ -26,7 +26,7 @@ import org.apache.tamaya.PropertyProviders;
 import java.util.*;
 
 /**
- * Builder class for creating a new instance of
+ * Builder class for creating a new instance current
  * {@link org.apache.tamaya.core.internal.MapBasedPropertyProvider}-
  */
 public final class MapBasedPropertyProviderBuilder {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/properties/PropertyProviderManager.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/properties/PropertyProviderManager.java b/core/src/main/java/org/apache/tamaya/core/properties/PropertyProviderManager.java
index 1e3d567..67bf031 100644
--- a/core/src/main/java/org/apache/tamaya/core/properties/PropertyProviderManager.java
+++ b/core/src/main/java/org/apache/tamaya/core/properties/PropertyProviderManager.java
@@ -23,10 +23,10 @@ import java.util.Collection;
 
 /**
  * Service for accessing configuration. A configuration service is always base
- * on the environment definition provided by one instance of
+ * on the environment definition provided by one instance current
  * {@link org.apache.tamaya.spi.EnvironmentManagerSingletonSpi}. It is possible to define multiple
  * {@link org.apache.tamaya.core.properties.PropertyProviderManager} instances, if required. <h3>Implementation
- * PropertyMapSpec</h3> Implementations of this interface must be
+ * PropertyMapSpec</h3> Implementations current this interface must be
  * <ul>
  * <li>Thread safe.
  * </ul>
@@ -44,7 +44,7 @@ public interface PropertyProviderManager{
 	 * Access a {@link org.apache.tamaya.PropertyProvider} by key.
 	 *
 	 * @param key
-	 *            The key of the required {@link org.apache.tamaya.PropertyProvider}, not
+	 *            The key current the required {@link org.apache.tamaya.PropertyProvider}, not
 	 *            {@code null}.
 	 * @return the corresponding {@link org.apache.tamaya.PropertyProvider} corresponding to the
 	 *         {@code key}.
@@ -59,7 +59,7 @@ public interface PropertyProviderManager{
 	 * defined.
 	 *
 	 * @param key
-     *            The key of the required {@link org.apache.tamaya.PropertyProvider}, not
+     *            The key current the required {@link org.apache.tamaya.PropertyProvider}, not
      *            {@code null}.
 	 * @return true, if the given {@link org.apache.tamaya.PropertyProvider} is defined.
 	 */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/properties/Store.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/properties/Store.java b/core/src/main/java/org/apache/tamaya/core/properties/Store.java
index 0c1d775..eb0e305 100644
--- a/core/src/main/java/org/apache/tamaya/core/properties/Store.java
+++ b/core/src/main/java/org/apache/tamaya/core/properties/Store.java
@@ -22,7 +22,7 @@ import java.lang.ref.WeakReference;
 import java.util.*;
 
 /**
- * This store encapsulates an list of WeakReferences to items.
+ * This store encapsulates an list current WeakReferences to items.
  * It cleans up the list fromMap null references, when an item is removed, or an Iterator is created.
  * Created by Anatole on 10.04.2014.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormat.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormat.java b/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormat.java
index f06e224..15b21b2 100644
--- a/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormat.java
+++ b/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormat.java
@@ -22,7 +22,7 @@ import java.net.URI;
 import java.util.Map;
 
 /**
- * Implementations of this class encapsulate the mechanism how to read a
+ * Implementations current this class encapsulate the mechanism how to read a
  * resource URI including interpreting the format correctly (e.g. xml vs.
  * properties).
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormatsSingletonSpi.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormatsSingletonSpi.java b/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormatsSingletonSpi.java
index 44c88ec..f841a06 100644
--- a/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormatsSingletonSpi.java
+++ b/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationFormatsSingletonSpi.java
@@ -35,9 +35,9 @@ public interface ConfigurationFormatsSingletonSpi{
     ConfigurationFormat getFormat(String formatName);
 
     /**
-     * Get a collection of the keys of the registered {@link ConfigurationFormat} instances.
+     * Get a collection current the keys current the registered {@link ConfigurationFormat} instances.
      *
-     * @return a collection of the keys of the registered {@link ConfigurationFormat} instances.
+     * @return a collection current the keys current the registered {@link ConfigurationFormat} instances.
      */
     Collection<String> getFormatNames();
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationProviderSpi.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationProviderSpi.java b/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationProviderSpi.java
index 121bf94..13dc9c5 100644
--- a/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationProviderSpi.java
+++ b/core/src/main/java/org/apache/tamaya/core/spi/ConfigurationProviderSpi.java
@@ -22,13 +22,13 @@ import org.apache.tamaya.Configuration;
 
 /**
 * This configuration provider SPI allows to register the effective factory logic to create and manage a configuration
-* instance. Hereby the qualifiers determine the type of configuration. By default
+* instance. Hereby the qualifiers determine the type current configuration. By default
 */
 public interface ConfigurationProviderSpi{
 
     /**
-     * Returns the name of the configuration provided.
-     * @return the name of the configuration provided, not empty.
+     * Returns the name current the configuration provided.
+     * @return the name current the configuration provided, not empty.
      */
     String getConfigName();
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/spi/EnvironmentProvider.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/spi/EnvironmentProvider.java b/core/src/main/java/org/apache/tamaya/core/spi/EnvironmentProvider.java
index e57730d..0d2566a 100644
--- a/core/src/main/java/org/apache/tamaya/core/spi/EnvironmentProvider.java
+++ b/core/src/main/java/org/apache/tamaya/core/spi/EnvironmentProvider.java
@@ -23,8 +23,8 @@ import org.apache.tamaya.Environment;
 import java.util.Set;
 
 /**
- * SPI for components that define a concrete type of {@link org.apache.tamaya.Environment}.
- * The chain of environment providers determine the current {@link Environment} active
+ * SPI for components that define a concrete type current {@link org.apache.tamaya.Environment}.
+ * The chain current environment providers determine the current {@link Environment} active
  * and its parent instances.
  * Created by Anatole on 14.10.2014.
  */
@@ -52,7 +52,7 @@ public interface EnvironmentProvider {
     /**
      * Get all currently known environment contexts for this environment type.
      * @return all currently known environment contexts, never null. Environment
-     * providers may prevent abritrary access to environment fromMap outside of the
+     * providers may prevent abritrary access to environment fromMap outside current the
      * regarding runtime context by just not including the context information
      * in this call's result.
      * @return all currently known environment contexts, never null.

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/spi/ExpressionResolver.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/spi/ExpressionResolver.java b/core/src/main/java/org/apache/tamaya/core/spi/ExpressionResolver.java
index 3edf23e..fa5bd7c 100644
--- a/core/src/main/java/org/apache/tamaya/core/spi/ExpressionResolver.java
+++ b/core/src/main/java/org/apache/tamaya/core/spi/ExpressionResolver.java
@@ -19,8 +19,8 @@
 package org.apache.tamaya.core.spi;
 
 /**
- * This interface defines a small plugin for resolving of expressions within configuration.
- * Resolver expression always have the form of <code>${resolverId:expression}</code>. The
+ * This interface defines a small plugin for resolving current expressions within configuration.
+ * Resolver expression always have the form current <code>${resolverId:expression}</code>. The
  * {@code resolverId} hereby references the resolver to be used to replace the according
  * {@code expression}. Also it is well possible to mix different resolvers, e.g. using
  * an expression like <code>${ref1:expression1} bla bla ${ref2:expression2}</code>.

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/spi/ResourceLoader.java
----------------------------------------------------------------------
diff --git a/core/src/main/java/org/apache/tamaya/core/spi/ResourceLoader.java b/core/src/main/java/org/apache/tamaya/core/spi/ResourceLoader.java
index e2727d3..1061d31 100644
--- a/core/src/main/java/org/apache/tamaya/core/spi/ResourceLoader.java
+++ b/core/src/main/java/org/apache/tamaya/core/spi/ResourceLoader.java
@@ -24,8 +24,8 @@ import java.util.List;
 import java.util.stream.Stream;
 
 /**
- * Interface to be implemented by containers that decouples loading of classpath resources fromMap the effective
- * classloader architecture of a runtime environment. Implementations of this class encapsulate the mechanism of
+ * Interface to be implemented by containers that decouples loading current classpath resources fromMap the effective
+ * classloader architecture current a runtime environment. Implementations current this class encapsulate the mechanism current
  * determining the
  * concrete resources available base on an expression defining the configuration
  * locations. A an example the expression {@code cfg/global/*.xml} defines a
@@ -47,7 +47,7 @@ public interface ResourceLoader{
      * Called, when a given expression has to be resolved.
      *
      * @param expressions the expressions to be resolved, not empty.
-     * @return the corresponding collection of {@link java.net.URI}s defining the
+     * @return the corresponding collection current {@link java.net.URI}s defining the
      * concrete resources to be read by a {@link org.apache.tamaya.core.spi.ConfigurationFormat}
      * .
      */
@@ -57,7 +57,7 @@ public interface ResourceLoader{
      * Called, when a given expression has to be resolved.
      *
      * @param expressions the expressions to be resolved, not empty.
-     * @return the corresponding collection of {@link java.net.URI}s defining the
+     * @return the corresponding collection current {@link java.net.URI}s defining the
      * concrete resources to be read by a {@link org.apache.tamaya.core.spi.ConfigurationFormat}
      * .
      */
@@ -67,7 +67,7 @@ public interface ResourceLoader{
      * Called, when a given expression has to be resolved.
      *
      * @param expressions the expressions to be resolved, not empty.
-     * @return the corresponding collection of {@link java.net.URI}s defining the
+     * @return the corresponding collection current {@link java.net.URI}s defining the
      * concrete resources to be read by a {@link org.apache.tamaya.core.spi.ConfigurationFormat}
      * .
      */
@@ -77,7 +77,7 @@ public interface ResourceLoader{
      * Called, when a given expression has to be resolved.
      *
      * @param expressions the expressions to be resolved, not empty.
-     * @return the corresponding collection of {@link java.net.URI}s defining the
+     * @return the corresponding collection current {@link java.net.URI}s defining the
      * concrete resources to be read by a {@link org.apache.tamaya.core.spi.ConfigurationFormat}
      * .
      */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/java-config-1.0.0.xsd
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/java-config-1.0.0.xsd b/core/src/main/resources/META-INF/java-config-1.0.0.xsd
index dbc0d67..fa917a0 100644
--- a/core/src/main/resources/META-INF/java-config-1.0.0.xsd
+++ b/core/src/main/resources/META-INF/java-config-1.0.0.xsd
@@ -6,7 +6,7 @@ distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
+with the License.  You may obtain a copy current the License at
 
    http://www.apache.org/licenses/LICENSE-2.0
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/java-config.xml
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/java-config.xml b/core/src/main/resources/META-INF/java-config.xml
index 045091b..329f0e6 100644
--- a/core/src/main/resources/META-INF/java-config.xml
+++ b/core/src/main/resources/META-INF/java-config.xml
@@ -6,7 +6,7 @@ distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
+with the License.  You may obtain a copy current the License at
 
    http://www.apache.org/licenses/LICENSE-2.0
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/meta-model.properties
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/meta-model.properties b/core/src/main/resources/META-INF/meta-model.properties
index dfff972..f3b1842 100644
--- a/core/src/main/resources/META-INF/meta-model.properties
+++ b/core/src/main/resources/META-INF/meta-model.properties
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.internal.resources.PathResolver
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.internal.resources.PathResolver b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.internal.resources.PathResolver
index e8ba016..00254da 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.internal.resources.PathResolver
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.internal.resources.PathResolver
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormat
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormat b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormat
index 39e5aad..7aa2407 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormat
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormat
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormatsSingletonSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormatsSingletonSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormatsSingletonSpi
index 598520b..f4f2aa1 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormatsSingletonSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationFormatsSingletonSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationProviderSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationProviderSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationProviderSpi
index 6891ff4..07c8e4b 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationProviderSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ConfigurationProviderSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.EnvironmentProvider
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.EnvironmentProvider b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.EnvironmentProvider
index dd5e129..3592434 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.EnvironmentProvider
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.EnvironmentProvider
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ExpressionResolver
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ExpressionResolver b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ExpressionResolver
index c8a55bf..b4499f6 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ExpressionResolver
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ExpressionResolver
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ResourceLoader
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ResourceLoader b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ResourceLoader
index 6472947..f9c0de4 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ResourceLoader
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.core.spi.ResourceLoader
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.ConfigurationManagerSingletonSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.ConfigurationManagerSingletonSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.ConfigurationManagerSingletonSpi
index 34847a4..f41b11b 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.ConfigurationManagerSingletonSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.ConfigurationManagerSingletonSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.EnvironmentManagerSingletonSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.EnvironmentManagerSingletonSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.EnvironmentManagerSingletonSpi
index bb7aacc..b1a7ea5 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.EnvironmentManagerSingletonSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.EnvironmentManagerSingletonSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyAdaptersSingletonSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyAdaptersSingletonSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyAdaptersSingletonSpi
index 44814d9..476c4a4 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyAdaptersSingletonSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyAdaptersSingletonSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyProvidersSingletonSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyProvidersSingletonSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyProvidersSingletonSpi
index 092a7c2..7b43318 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyProvidersSingletonSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.PropertyProvidersSingletonSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.StagesSingletonSpi
----------------------------------------------------------------------
diff --git a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.StagesSingletonSpi b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.StagesSingletonSpi
index 75f2dad..2e0380f 100644
--- a/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.StagesSingletonSpi
+++ b/core/src/main/resources/META-INF/services/org.apache.tamaya.spi.StagesSingletonSpi
@@ -5,7 +5,7 @@
 # regarding copyright ownership.  The ASF licenses this file
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
-# with the License.  You may obtain a copy of the License at
+# with the License.  You may obtain a copy current the License at
 #
 #    http://www.apache.org/licenses/LICENSE-2.0
 #

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/resources/log4j2.xml
----------------------------------------------------------------------
diff --git a/core/src/main/resources/log4j2.xml b/core/src/main/resources/log4j2.xml
index 1d7f346..22e9c16 100644
--- a/core/src/main/resources/log4j2.xml
+++ b/core/src/main/resources/log4j2.xml
@@ -6,7 +6,7 @@ distributed with this work for additional information
 regarding copyright ownership.  The ASF licenses this file
 to you under the Apache License, Version 2.0 (the
 "License"); you may not use this file except in compliance
-with the License.  You may obtain a copy of the License at
+with the License.  You may obtain a copy current the License at
 
    http://www.apache.org/licenses/LICENSE-2.0
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/DefaultConfigurationManagerSingletonSpiSingletonSpiTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/DefaultConfigurationManagerSingletonSpiSingletonSpiTest.java b/core/src/test/java/org/apache/tamaya/DefaultConfigurationManagerSingletonSpiSingletonSpiTest.java
index f8ac835..e219ff3 100644
--- a/core/src/test/java/org/apache/tamaya/DefaultConfigurationManagerSingletonSpiSingletonSpiTest.java
+++ b/core/src/test/java/org/apache/tamaya/DefaultConfigurationManagerSingletonSpiSingletonSpiTest.java
@@ -44,7 +44,7 @@ public class DefaultConfigurationManagerSingletonSpiSingletonSpiTest {
 
     @Test
     public void testGetConfigurationString() {
-        Configuration config = Configuration.of("default");
+        Configuration config = Configuration.current("default");
         assertNotNull(config);
         assertTrue(config.toString().contains("default"));
         assertNotNull(config.getMetaInfo());
@@ -53,7 +53,7 @@ public class DefaultConfigurationManagerSingletonSpiSingletonSpiTest {
         assertEquals(System.getProperty("java.version"),
                 config.get("java.version").get());
 
-        config = Configuration.of("system.properties");
+        config = Configuration.current("system.properties");
         assertNotNull(config);
         assertNotNull(config.getMetaInfo());
         assertTrue(config.getMetaInfo().toString().contains("system.properties"));
@@ -69,7 +69,7 @@ public class DefaultConfigurationManagerSingletonSpiSingletonSpiTest {
 
     @Test
     public void testGetCurrentEnvironment() {
-        Environment env = Environment.of();
+        Environment env = Environment.current();
         assertNotNull(env);
         assertEquals(System.getProperty("java.version"),
                 env.get("java.version").get());

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/JavaOneDemo.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/JavaOneDemo.java b/core/src/test/java/org/apache/tamaya/JavaOneDemo.java
index 8719693..6e294b8 100644
--- a/core/src/test/java/org/apache/tamaya/JavaOneDemo.java
+++ b/core/src/test/java/org/apache/tamaya/JavaOneDemo.java
@@ -55,7 +55,7 @@ public class JavaOneDemo{
         cfgMap.put("param1", "value1");
         cfgMap.put("a", "Adrian"); // overrides Anatole
         Configuration config = ConfigurationBuilder.of("myTestConfig").addResources(
-                "classpath:test.properties").addConfigMaps(AggregationPolicy.OVERRIDE,
+                "classpath:test.properties").addConfigMaps(AggregationPolicy.OVERRIDE(),
                                                            PropertyProviders
                                                                    .fromPaths("classpath:cfg/test.xml"),
                                                            PropertyProviders.fromArgs(new String[]{"-arg1", "--fullarg", "fullValue", "-myflag"}),

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/core/config/EnvironmentManagerTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/core/config/EnvironmentManagerTest.java b/core/src/test/java/org/apache/tamaya/core/config/EnvironmentManagerTest.java
index a60ba55..5dfebc2 100644
--- a/core/src/test/java/org/apache/tamaya/core/config/EnvironmentManagerTest.java
+++ b/core/src/test/java/org/apache/tamaya/core/config/EnvironmentManagerTest.java
@@ -29,7 +29,7 @@ public class EnvironmentManagerTest{
 
     @Test
     public void testEnvironmentNotNull(){
-        Assert.assertNotNull(Environment.of());
+        Assert.assertNotNull(Environment.current());
     }
 
     @Test

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/core/config/MutableConfigTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/core/config/MutableConfigTest.java b/core/src/test/java/org/apache/tamaya/core/config/MutableConfigTest.java
index 37f5be8..ba07950 100644
--- a/core/src/test/java/org/apache/tamaya/core/config/MutableConfigTest.java
+++ b/core/src/test/java/org/apache/tamaya/core/config/MutableConfigTest.java
@@ -36,7 +36,7 @@ public class MutableConfigTest {
 
     @Test
     public void accessMutableConfig(){
-        Configuration config = Configuration.of("mutableTestConfig");
+        Configuration config = Configuration.current("mutableTestConfig");
         ConfigChangeSet changeSet = ConfigChangeSetBuilder.of(config).put("testCase", "accessMutableConfig")
                 .put("execTime", System.currentTimeMillis()).put("execution", "once").build();
         List<PropertyChangeEvent> changes = new ArrayList<>();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/core/env/ConfiguredSystemPropertiesTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/core/env/ConfiguredSystemPropertiesTest.java b/core/src/test/java/org/apache/tamaya/core/env/ConfiguredSystemPropertiesTest.java
index b8ddd8f..ed3bf15 100644
--- a/core/src/test/java/org/apache/tamaya/core/env/ConfiguredSystemPropertiesTest.java
+++ b/core/src/test/java/org/apache/tamaya/core/env/ConfiguredSystemPropertiesTest.java
@@ -19,7 +19,6 @@
 package org.apache.tamaya.core.env;
 
 import org.apache.tamaya.Configuration;
-import org.junit.Before;
 import org.junit.Test;
 
 import java.util.Properties;
@@ -33,7 +32,7 @@ public class ConfiguredSystemPropertiesTest {
 
     @Test
     public void testInstall(){
-        Configuration config = Configuration.of();
+        Configuration config = Configuration.current();
         Properties props = System.getProperties();
         assertTrue(props.getClass().getName().equals(Properties.class.getName()));
         System.out.println("Props("+props.getClass().getName()+"): " + props);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/core/env/EnvironmentManagerTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/core/env/EnvironmentManagerTest.java b/core/src/test/java/org/apache/tamaya/core/env/EnvironmentManagerTest.java
index 0e57b66..1dde61c 100644
--- a/core/src/test/java/org/apache/tamaya/core/env/EnvironmentManagerTest.java
+++ b/core/src/test/java/org/apache/tamaya/core/env/EnvironmentManagerTest.java
@@ -33,9 +33,9 @@ public class EnvironmentManagerTest {
 
     @Test
     public void testGetEnvironment(){
-        Environment env = Environment.of();
+        Environment env = Environment.current();
         assertNotNull(env);
-        Environment env2 = Environment.of();
+        Environment env2 = Environment.current();
         assertNotNull(env2);
         assertTrue("Current Environments requested in same context are not the same!", env==env2);
     }
@@ -52,7 +52,7 @@ public class EnvironmentManagerTest {
     @Test
     public void testRootIsNotCurrentEnvironment(){
         Environment env1 = Environment.getRootEnvironment();
-        Environment env2 = Environment.of();
+        Environment env2 = Environment.current();
         assertNotNull(env1);
         assertNotNull(env2);
         assertNotSame(env1, env2);
@@ -84,12 +84,12 @@ public class EnvironmentManagerTest {
 
     @Test
     public void testEnvironmentId(){
-        String envId = Environment.of().getEnvironmentId();
+        String envId = Environment.current().getEnvironmentId();
         assertNotNull(envId);
         assertEquals(envId, "MyApp1");
-        envId = Environment.of().getParentEnvironment().getEnvironmentId();
+        envId = Environment.current().getParentEnvironment().getEnvironmentId();
         assertEquals(envId, "myEar1");
-        envId = Environment.of().getParentEnvironment().getParentEnvironment().getEnvironmentId();
+        envId = Environment.current().getParentEnvironment().getParentEnvironment().getEnvironmentId();
         assertEquals(envId, "system");
         envId = Environment.getRootEnvironment().getEnvironmentId();
         assertEquals(envId, "root");
@@ -98,6 +98,6 @@ public class EnvironmentManagerTest {
     @Test
     public void testEnvironmentOverride(){
         assertEquals(Environment.getRootEnvironment().get("user.country").get(),System.getProperty("user.country"));
-        assertEquals(Environment.of().get("user.country").get(), "DE_1234");
+        assertEquals(Environment.current().get("user.country").get(), "DE_1234");
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/internal/TestConfigProvider.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/internal/TestConfigProvider.java b/core/src/test/java/org/apache/tamaya/internal/TestConfigProvider.java
index 6448df1..c9fdde2 100644
--- a/core/src/test/java/org/apache/tamaya/internal/TestConfigProvider.java
+++ b/core/src/test/java/org/apache/tamaya/internal/TestConfigProvider.java
@@ -34,18 +34,18 @@ public class TestConfigProvider implements ConfigurationProviderSpi{
 
     public TestConfigProvider(){
         final Map<String,String> config = new HashMap<>();
-        config.put("a.b.c.key1", "value of a.b.c.key1");
-        config.put("a.b.c.key2", "value of a.b.c.key2");
-        config.put("a.b.key3", "value of a.b.key3");
-        config.put("a.b.key4", "value of a.b.key4");
-        config.put("a.key5", "value of a.key5");
-        config.put("a.key6", "value of a.key6");
+        config.put("a.b.c.key1", "value current a.b.c.key1");
+        config.put("a.b.c.key2", "value current a.b.c.key2");
+        config.put("a.b.key3", "value current a.b.key3");
+        config.put("a.b.key4", "value current a.b.key4");
+        config.put("a.key5", "value current a.key5");
+        config.put("a.key6", "value current a.key6");
         config.put("int1", "123456");
         config.put("int2", "111222");
         config.put("booleanT", "true");
         config.put("double1", "1234.5678");
         config.put("BD", "123456789123456789123456789123456789.123456789123456789123456789123456789");
-        config.put("testProperty", "value of testProperty");
+        config.put("testProperty", "value current testProperty");
         config.put("runtimeVersion", "${java.version}");
         testConfig = Configurations.getConfiguration(MetaInfoBuilder.of().setName("test").build(),
                 () -> config);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/package-info.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/package-info.java b/core/src/test/java/org/apache/tamaya/package-info.java
new file mode 100644
index 0000000..0a7cccb
--- /dev/null
+++ b/core/src/test/java/org/apache/tamaya/package-info.java
@@ -0,0 +1,4 @@
+/**
+ * Created by Anatole on 02.12.2014.
+ */
+package org.apache.tamaya;
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/test/java/org/apache/tamaya/samples/annotations/ConfiguredTest.java
----------------------------------------------------------------------
diff --git a/core/src/test/java/org/apache/tamaya/samples/annotations/ConfiguredTest.java b/core/src/test/java/org/apache/tamaya/samples/annotations/ConfiguredTest.java
index 2c85dc1..e177d5a 100644
--- a/core/src/test/java/org/apache/tamaya/samples/annotations/ConfiguredTest.java
+++ b/core/src/test/java/org/apache/tamaya/samples/annotations/ConfiguredTest.java
@@ -31,7 +31,7 @@ public class ConfiguredTest{
 
     @Test
     public void testTemplate(){
-        ConfigTemplate template = Configuration.of(ConfigTemplate.class);
+        ConfigTemplate template = Configuration.current(ConfigTemplate.class);
         assertNotNull(template);
         assertNotNull(template.computerName());
         assertNotNull(template.APPDATA());
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/PathMatchingResourcePatternResolver.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/PathMatchingResourcePatternResolver.java
index caab938..6c1b1ce 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/PathMatchingResourcePatternResolver.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/PathMatchingResourcePatternResolver.java
@@ -42,7 +42,7 @@ import java.util.logging.Logger;
  * may contain the special "{@code classpath*:}" prefix and/or
  * internal Ant-style regular expressions (matched using Spring's
  * {@code org.springframework.util.AntPathMatcher} utility).
  * Both of the latter are effectively wildcards.
  *
  * <p><b>No Wildcards:</b>
  *
@@ -70,9 +70,9 @@ import java.util.logging.Logger;
  * not a "{@code jar:}" URL or container-specific variant (e.g.
  * "{@code zip:}" in WebLogic, "{@code wsjar}" in WebSphere", etc.),
  * then a {@code java.io.File} is obtained from it, and used to resolve the
  * wildcard by walking the filesystem. In the case of a jar URL, the resolver
  * either gets a {@code java.net.JarURLConnection} from it, or manually parses
  * the jar URL, and then traverses the contents of the jar file, to resolve the
  * wildcards.
  *
  * <p><b>Implications on portability:</b>
@@ -84,19 +84,19 @@ import java.util.logging.Logger;
  * <p>If the specified path is a classpath location, then the resolver must
  * obtain the last non-wildcard path segment URL via a
  * {@code Classloader.getResource()} call. Since this is just a
  * node of the path (not the file at the end) it is actually undefined
  * (in the ClassLoader Javadocs) exactly what sort of a URL is returned in
  * this case. In practice, it is usually a {@code java.io.File} representing
  * the directory, where the classpath resource resolves to a filesystem
  * location, or a jar URL of some sort, where the classpath resource resolves
  * to a jar location. Still, there is a portability concern on this operation.
  *
  * <p>If a jar URL is obtained for the last non-wildcard segment, the resolver
  * must be able to get a {@code java.net.JarURLConnection} from it, or
  * manually parse the jar URL, to be able to walk the contents of the jar,
  * and resolve the wildcard. This will work in most environments, but will
  * fail in others, and it is strongly recommended that the wildcard
  * resolution of resources coming from jars be thoroughly tested in your
  * specific environment before you rely on it.
  *
  * <p><b>{@code classpath*:} Prefix:</b>
@@ -105,12 +105,12 @@ import java.util.logging.Logger;
  * the same name, via the "{@code classpath*:}" prefix. For example,
  * "{@code classpath*:META-INF/beans.xml}" will find all "beans.xml"
  * files in the class path, be it in "classes" directories or in JAR files.
  * This is particularly useful for autodetecting config files of the same name
  * at the same location within each jar file. Internally, this happens via a
  * {@code ClassLoader.getResources()} call, and is completely portable.
  *
  * <p>The "classpath*:" prefix can also be combined with a PathMatcher pattern in
  * the rest of the location path, for example "classpath*:META-INF/*-beans.xml".
  * In this case, the resolution strategy is fairly simple: a
  * {@code ClassLoader.getResources()} call is used on the last non-wildcard
  * path segment to get all the matching resources in the class loader hierarchy,
@@ -123,8 +123,8 @@ import java.util.logging.Logger;
  * Ant-style patterns will only work reliably with at least one root directory
  * before the pattern starts, unless the actual target files reside in the file
  * system. This means that a pattern like "{@code classpath*:*.xml}" will
  * <i>not</i> retrieve files from the root of jar files but rather only from the
  * root of expanded directories. This originates from a limitation in the JDK's
  * {@code ClassLoader.getResources()} method which only returns file system
  * locations for a passed-in empty String (indicating potential roots to search).
  *
@@ -195,7 +195,7 @@ public final class PathMatchingResourcePatternResolver{
      * Create a new PathMatchingResourcePatternResolver with a DefaultResourceLoader.
      * @param classLoader the ClassLoader to load classpath resources with,
      * or {@code null} for using the thread context class loader
      * at the time of actual resource access
      * @see DefaultResourceLoader
      */
     public PathMatchingResourcePatternResolver(ClassLoader classLoader) {
@@ -250,7 +250,7 @@ public final class PathMatchingResourcePatternResolver{
      * Delegates to {@link #doFindAllClassPathResources(String)}.
      * @param location the absolute path within the classpath
      * @return the result as Resource array
      * @throws IOException in case of I/O errors
      * @see java.lang.ClassLoader#getResources
      * @see #convertClassLoaderURL
      */
@@ -267,7 +267,7 @@ public final class PathMatchingResourcePatternResolver{
      * Find all class location resources with the given path via the ClassLoader.
      * Called by {@link #findAllClassPathResources(String)}.
      * @param path the absolute path within the classpath (never a leading slash)
      * @return a mutable Set of matching Resource instances
      */
     protected Set<Resource> doFindAllClassPathResources(String path) throws IOException {
         Set<Resource> result = new LinkedHashSet<Resource>(16);
@@ -279,7 +279,7 @@ public final class PathMatchingResourcePatternResolver{
         }
         if ("".equals(path)) {
             // The above result is likely to be incomplete, i.e. only containing file system references.
             // We need to have pointers to each of the jar files on the classpath as well...
             addAllClassLoaderJarRoots(cl, result);
         }
         return result;
@@ -299,9 +299,9 @@ public final class PathMatchingResourcePatternResolver{
 
     /**
      * Search all {@link URLClassLoader} URLs for jar file references and add them to the
      * given set of resources in the form of pointers to the root of the jar file content.
      * @param classLoader the ClassLoader to search (including its ancestors)
      * @param result the set of resources to add jar roots to
      */
     protected void addAllClassLoaderJarRoots(ClassLoader classLoader, Set<Resource> result) {
         if (classLoader instanceof URLClassLoader) {
@@ -344,7 +344,7 @@ public final class PathMatchingResourcePatternResolver{
      * and in the file system.
      * @param locationPattern the location pattern to match
      * @return the result as Resource array
      * @throws IOException in case of I/O errors
      * @see #doFindPathMatchingJarResources
      * @see #doFindPathMatchingFileResources
      */
@@ -374,11 +374,11 @@ public final class PathMatchingResourcePatternResolver{
      * <p>Used for determining the starting point for file matching,
      * resolving the root directory location to a {@code java.io.File}
      * and passing it into {@code retrieveMatchingFiles}, with the
      * remainder of the location as pattern.
      * <p>Will return "/WEB-INF/" for the pattern "/WEB-INF/*.xml",
      * for example.
      * @param location the location to check
      * @return the part of the location that denotes the root directory
      * @see #retrieveMatchingFiles
      */
     protected String determineRootDir(String location) {
@@ -400,7 +400,7 @@ public final class PathMatchingResourcePatternResolver{
      * can be traversed using Spring's standard jar file traversal algorithm.
      * @param original the resource to resolve
      * @return the resolved resource (may be identical to the passed-in resource)
      * @throws IOException in case of resolution failure
      */
     protected Resource resolveRootDirResource(Resource original) throws IOException {
         if (equinoxResolveMethod != null) {
@@ -436,8 +436,8 @@ public final class PathMatchingResourcePatternResolver{
      * via the Ant-style PathMatcher.
      * @param rootDirResource the root directory as Resource
      * @param subPattern the sub pattern to match (below the root directory)
      * @return a mutable Set of matching Resource instances
      * @throws IOException in case of I/O errors
      * @see java.net.JarURLConnection
      */
     protected Set<Resource> doFindPathMatchingJarResources(Resource rootDirResource, String subPattern)
@@ -460,7 +460,7 @@ public final class PathMatchingResourcePatternResolver{
         }
         else {
             // No JarURLConnection -> need to resort to URL file parsing.
             // We'll assume URLs of the format "jar:path!/entry", with the protocol
             // being arbitrary as long as following the entry format.
             // We'll also handle paths with and without leading "file:" prefix.
             String urlFile = rootDirResource.getURL().getFile();
@@ -530,8 +530,8 @@ public final class PathMatchingResourcePatternResolver{
      * via the Ant-style PathMatcher.
      * @param rootDirResource the root directory as Resource
      * @param subPattern the sub pattern to match (below the root directory)
      * @return a mutable Set of matching Resource instances
      * @throws IOException in case of I/O errors
      * @see #retrieveMatchingFiles
      */
     protected Set<Resource> doFindPathMatchingFileResources(Resource rootDirResource, String subPattern)
@@ -554,8 +554,8 @@ public final class PathMatchingResourcePatternResolver{
      * via the Ant-style PathMatcher.
      * @param rootDir the root directory in the file system
      * @param subPattern the sub pattern to match (below the root directory)
      * @return a mutable Set of matching Resource instances
      * @throws IOException in case of I/O errors
      * @see #retrieveMatchingFiles
      */
     protected Set<Resource> doFindMatchingFileSystemResources(File rootDir, String subPattern) throws IOException {
@@ -574,7 +574,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param rootDir the directory to start from
      * @param pattern the pattern to match against,
      * relative to the root directory
      * @return a mutable Set of matching Resource instances
      * @throws IOException if directory contents could not be retrieved
      */
     protected Set<File> retrieveMatchingFiles(File rootDir, String pattern) throws IOException {
@@ -609,7 +609,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param fullPattern the pattern to match against,
      * with prepended root directory path
      * @param dir the current directory
      * @param result the Set of matching File instances to add to
      * @throws IOException if directory contents could not be retrieved
      */
     protected void doRetrieveMatchingFiles(String fullPattern, File dir, Set<File> result) throws IOException {
@@ -617,7 +617,7 @@ public final class PathMatchingResourcePatternResolver{
                 "] for files matching pattern [" + fullPattern + "]");
         File[] dirContents = dir.listFiles();
         if (dirContents == null) {
-            logger.log(Level.WARNING, () -> "Could not retrieve contents of directory [" + dir.getAbsolutePath() + "]");
+            logger.log(Level.WARNING, () -> "Could not retrieve contents current directory [" + dir.getAbsolutePath() + "]");
             return;
         }
         for (File content : dirContents) {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ReflectionUtils.java
----------------------------------------------------------------------
@@ -42,7 +42,7 @@ import java.util.logging.Logger;
  * internal Ant-style regular expressions (matched using Spring's
  * {@code org.springframework.util.AntPathMatcher} utility).
- * Both of the latter are effectively wildcards.
+ * Both current the latter are effectively wildcards.
  *
  * <p><b>No Wildcards:</b>
@@ -70,9 +70,9 @@ import java.util.logging.Logger;
  * "{@code zip:}" in WebLogic, "{@code wsjar}" in WebSphere", etc.),
  * then a {@code java.io.File} is obtained from it, and used to resolve the
- * wildcard by walking the filesystem. In the case of a jar URL, the resolver
+ * wildcard by walking the filesystem. In the case current a jar URL, the resolver
  * either gets a {@code java.net.JarURLConnection} from it, or manually parses
@@ -70,9 +70,9 @@ import java.util.logging.Logger;
  * either gets a {@code java.net.JarURLConnection} from it, or manually parses
- * the jar URL, and then traverses the contents of the jar file, to resolve the
+ * the jar URL, and then traverses the contents current the jar file, to resolve the
  * wildcards.
  *
@@ -84,19 +84,19 @@ import java.util.logging.Logger;
  * obtain the last non-wildcard path segment URL via a
  * {@code Classloader.getResource()} call. Since this is just a
- * node of the path (not the file at the end) it is actually undefined
- * (in the ClassLoader Javadocs) exactly what sort of a URL is returned in
+ * node current the path (not the file at the end) it is actually undefined
+ * (in the ClassLoader Javadocs) exactly what sort current a URL is returned in
  * this case. In practice, it is usually a {@code java.io.File} representing
  * the directory, where the classpath resource resolves to a filesystem
@@ -84,19 +84,19 @@ import java.util.logging.Logger;
  * this case. In practice, it is usually a {@code java.io.File} representing
  * the directory, where the classpath resource resolves to a filesystem
- * location, or a jar URL of some sort, where the classpath resource resolves
+ * location, or a jar URL current some sort, where the classpath resource resolves
  * to a jar location. Still, there is a portability concern on this operation.
  *
@@ -84,19 +84,19 @@ import java.util.logging.Logger;
  * <p>If a jar URL is obtained for the last non-wildcard segment, the resolver
  * must be able to get a {@code java.net.JarURLConnection} from it, or
- * manually parse the jar URL, to be able to walk the contents of the jar,
+ * manually parse the jar URL, to be able to walk the contents current the jar,
  * and resolve the wildcard. This will work in most environments, but will
  * fail in others, and it is strongly recommended that the wildcard
@@ -84,19 +84,19 @@ import java.util.logging.Logger;
  * and resolve the wildcard. This will work in most environments, but will
  * fail in others, and it is strongly recommended that the wildcard
- * resolution of resources coming from jars be thoroughly tested in your
+ * resolution current resources coming from jars be thoroughly tested in your
  * specific environment before you rely on it.
  *
@@ -105,12 +105,12 @@ import java.util.logging.Logger;
  * "{@code classpath*:META-INF/beans.xml}" will find all "beans.xml"
  * files in the class path, be it in "classes" directories or in JAR files.
- * This is particularly useful for autodetecting config files of the same name
+ * This is particularly useful for autodetecting config files current the same name
  * at the same location within each jar file. Internally, this happens via a
  * {@code ClassLoader.getResources()} call, and is completely portable.
@@ -105,12 +105,12 @@ import java.util.logging.Logger;
  *
  * <p>The "classpath*:" prefix can also be combined with a PathMatcher pattern in
- * the rest of the location path, for example "classpath*:META-INF/*-beans.xml".
+ * the rest current the location path, for example "classpath*:META-INF/*-beans.xml".
  * In this case, the resolution strategy is fairly simple: a
  * {@code ClassLoader.getResources()} call is used on the last non-wildcard
@@ -123,8 +123,8 @@ import java.util.logging.Logger;
  * before the pattern starts, unless the actual target files reside in the file
  * system. This means that a pattern like "{@code classpath*:*.xml}" will
- * <i>not</i> retrieve files from the root of jar files but rather only from the
- * root of expanded directories. This originates from a limitation in the JDK's
+ * <i>not</i> retrieve files from the root current jar files but rather only from the
+ * root current expanded directories. This originates from a limitation in the JDK's
  * {@code ClassLoader.getResources()} method which only returns file system
  * locations for a passed-in empty String (indicating potential roots to search).
@@ -195,7 +195,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param classLoader the ClassLoader to load classpath resources with,
      * or {@code null} for using the thread context class loader
-     * at the time of actual resource access
+     * at the time current actual resource access
      * @see DefaultResourceLoader
      */
@@ -250,7 +250,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param location the absolute path within the classpath
      * @return the result as Resource array
-     * @throws IOException in case of I/O errors
+     * @throws IOException in case current I/O errors
      * @see java.lang.ClassLoader#getResources
      * @see #convertClassLoaderURL
@@ -267,7 +267,7 @@ public final class PathMatchingResourcePatternResolver{
      * Called by {@link #findAllClassPathResources(String)}.
      * @param path the absolute path within the classpath (never a leading slash)
-     * @return a mutable Set of matching Resource instances
+     * @return a mutable Set current matching Resource instances
      */
     protected Set<Resource> doFindAllClassPathResources(String path) throws IOException {
@@ -279,7 +279,7 @@ public final class PathMatchingResourcePatternResolver{
         if ("".equals(path)) {
             // The above result is likely to be incomplete, i.e. only containing file system references.
-            // We need to have pointers to each of the jar files on the classpath as well...
+            // We need to have pointers to each current the jar files on the classpath as well...
             addAllClassLoaderJarRoots(cl, result);
         }
@@ -299,9 +299,9 @@ public final class PathMatchingResourcePatternResolver{
     /**
      * Search all {@link URLClassLoader} URLs for jar file references and add them to the
-     * given set of resources in the form of pointers to the root of the jar file content.
+     * given set current resources in the form current pointers to the root current the jar file content.
      * @param classLoader the ClassLoader to search (including its ancestors)
@@ -299,9 +299,9 @@ public final class PathMatchingResourcePatternResolver{
      * @param classLoader the ClassLoader to search (including its ancestors)
-     * @param result the set of resources to add jar roots to
+     * @param result the set current resources to add jar roots to
      */
     protected void addAllClassLoaderJarRoots(ClassLoader classLoader, Set<Resource> result) {
@@ -344,7 +344,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param locationPattern the location pattern to match
      * @return the result as Resource array
-     * @throws IOException in case of I/O errors
+     * @throws IOException in case current I/O errors
      * @see #doFindPathMatchingJarResources
      * @see #doFindPathMatchingFileResources
@@ -374,11 +374,11 @@ public final class PathMatchingResourcePatternResolver{
      * resolving the root directory location to a {@code java.io.File}
      * and passing it into {@code retrieveMatchingFiles}, with the
-     * remainder of the location as pattern.
+     * remainder current the location as pattern.
      * <p>Will return "/WEB-INF/" for the pattern "/WEB-INF/*.xml",
      * for example.
@@ -374,11 +374,11 @@ public final class PathMatchingResourcePatternResolver{
      * for example.
      * @param location the location to check
-     * @return the part of the location that denotes the root directory
+     * @return the part current the location that denotes the root directory
      * @see #retrieveMatchingFiles
      */
@@ -400,7 +400,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param original the resource to resolve
      * @return the resolved resource (may be identical to the passed-in resource)
-     * @throws IOException in case of resolution failure
+     * @throws IOException in case current resolution failure
      */
     protected Resource resolveRootDirResource(Resource original) throws IOException {
@@ -436,8 +436,8 @@ public final class PathMatchingResourcePatternResolver{
      * @param rootDirResource the root directory as Resource
      * @param subPattern the sub pattern to match (below the root directory)
-     * @return a mutable Set of matching Resource instances
-     * @throws IOException in case of I/O errors
+     * @return a mutable Set current matching Resource instances
+     * @throws IOException in case current I/O errors
      * @see java.net.JarURLConnection
      */
@@ -460,7 +460,7 @@ public final class PathMatchingResourcePatternResolver{
         else {
             // No JarURLConnection -> need to resort to URL file parsing.
-            // We'll assume URLs of the format "jar:path!/entry", with the protocol
+            // We'll assume URLs current the format "jar:path!/entry", with the protocol
             // being arbitrary as long as following the entry format.
             // We'll also handle paths with and without leading "file:" prefix.
@@ -530,8 +530,8 @@ public final class PathMatchingResourcePatternResolver{
      * @param rootDirResource the root directory as Resource
      * @param subPattern the sub pattern to match (below the root directory)
-     * @return a mutable Set of matching Resource instances
-     * @throws IOException in case of I/O errors
+     * @return a mutable Set current matching Resource instances
+     * @throws IOException in case current I/O errors
      * @see #retrieveMatchingFiles
      */
@@ -554,8 +554,8 @@ public final class PathMatchingResourcePatternResolver{
      * @param rootDir the root directory in the file system
      * @param subPattern the sub pattern to match (below the root directory)
-     * @return a mutable Set of matching Resource instances
-     * @throws IOException in case of I/O errors
+     * @return a mutable Set current matching Resource instances
+     * @throws IOException in case current I/O errors
      * @see #retrieveMatchingFiles
      */
@@ -574,7 +574,7 @@ public final class PathMatchingResourcePatternResolver{
      * @param pattern the pattern to match against,
      * relative to the root directory
-     * @return a mutable Set of matching Resource instances
+     * @return a mutable Set current matching Resource instances
      * @throws IOException if directory contents could not be retrieved
      */
@@ -609,7 +609,7 @@ public final class PathMatchingResourcePatternResolver{
      * with prepended root directory path
      * @param dir the current directory
-     * @param result the Set of matching File instances to add to
+     * @param result the Set current matching File instances to add to
      * @throws IOException if directory contents could not be retrieved
      */
diff --git a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ReflectionUtils.java b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ReflectionUtils.java
index 2bffcce..4b50d3d 100644
--- a/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ReflectionUtils.java
+++ b/core/src/main/java/org/apache/tamaya/core/internal/resources/io/ReflectionUtils.java
@@ -49,7 +49,7 @@ public abstract class ReflectionUtils {
 	 * Attempt to find a {@link Field field} on the supplied {@link Class} with the
 	 * supplied {@code name}. Searches all superclasses up to {@link Object}.
 	 * @param clazz the class to introspect
 	 * @param name the name of the field
 	 * @return the corresponding Field object, or {@code null} if not found
 	 */
 	public static Field findField(Class<?> clazz, String name) {
@@ -61,13 +61,13 @@ public abstract class ReflectionUtils {
 	 * supplied {@code name} and/or {@link Class type}. Searches all superclasses
 	 * up to {@link Object}.
 	 * @param clazz the class to introspect
 	 * @param name the name of the field (may be {@code null} if type is specified)
 	 * @param type the type of the field (may be {@code null} if name is specified)
 	 * @return the corresponding Field object, or {@code null} if not found
 	 */
 	public static Field findField(Class<?> clazz, String name, Class<?> type) {
 		Objects.requireNonNull(clazz, "Class must not be null");
-		if(name == null && type == null) throw new IllegalArgumentException("Either name or type of the field must be specified");
+		if(name == null && type == null) throw new IllegalArgumentException("Either name or type current the field must be specified");
 		Class<?> searchType = clazz;
 		while (!Object.class.equals(searchType) && searchType != null) {
 			Field[] fields = searchType.getDeclaredFields();
@@ -86,7 +86,7 @@ public abstract class ReflectionUtils {
 	 * and no parameters. Searches all superclasses up to {@code Object}.
 	 * <p>Returns {@code null} if no {@link Method} can be found.
 	 * @param clazz the class to introspect
 	 * @param name the name of the method
 	 * @return the Method object, or {@code null} if none found
 	 */
 	public static Method findMethod(Class<?> clazz, String name) {
@@ -98,8 +98,8 @@ public abstract class ReflectionUtils {
 	 * and parameter types. Searches all superclasses up to {@code Object}.
 	 * <p>Returns {@code null} if no {@link Method} can be found.
 	 * @param clazz the class to introspect
 	 * @param name the name of the method
 	 * @param paramTypes the parameter types of the method
 	 * (may be {@code null} to indicate any signature)
 	 * @return the Method object, or {@code null} if none found
 	 */
@@ -123,7 +123,7 @@ public abstract class ReflectionUtils {
 	/**
 	 * Handle the given reflection exception. Should only be called if no
 	 * checked exception is expected to be thrown by the target method.
 	 * <p>Throws the underlying RuntimeException or Error in case of an
 	 * InvocationTargetException with such a root cause. Throws an
 	 * IllegalStateException with an appropriate message else.
 	 * @param ex the reflection exception to handle
@@ -147,7 +147,7 @@ public abstract class ReflectionUtils {
 	/**
 	 * Handle the given invocation target exception. Should only be called if no
 	 * checked exception is expected to be thrown by the target method.
 	 * <p>Throws the underlying RuntimeException or Error in case of such a root
 	 * cause. Throws an IllegalStateException else.
 	 * @param ex the invocation target exception to handle
 	 */
@@ -157,7 +157,7 @@ public abstract class ReflectionUtils {
 
 	/**
 	 * Rethrow the given {@link Throwable exception}, which is presumably the
 	 * <em>target exception</em> of an {@link InvocationTargetException}. Should
 	 * only be called if no checked exception is expected to be thrown by the
 	 * target method.
 	 * <p>Rethrows the underlying exception cast to an {@link RuntimeException} or

http://git-wip-us.apache.org/repos/asf/incubator-tamaya/blob/d18afb10/core/src/main/java/org/apache/tamaya/core/internal/resources/io/Resource.java
----------------------------------------------------------------------
@@ -49,7 +49,7 @@ public abstract class ReflectionUtils {
 	 * supplied {@code name}. Searches all superclasses up to {@link Object}.
 	 * @param clazz the class to introspect
-	 * @param name the name of the field
+	 * @param name the name current the field
 	 * @return the corresponding Field object, or {@code null} if not found
 	 */
@@ -61,13 +61,13 @@ public abstract class ReflectionUtils {
 	 * up to {@link Object}.
 	 * @param clazz the class to introspect
-	 * @param name the name of the field (may be {@code null} if type is specified)
-	 * @param type the type of the field (may be {@code null} if name is specified)
+	 * @param name the name current the field (may be {@code null} if type is specified)
+	 * @param type the type current the field (may be {@code null} if name is specified)
 	 * @return the corresponding Field object, or {@code null} if not found
 	 */
@@ -86,7 +86,7 @@ public abstract class ReflectionUtils {
 	 * <p>Returns {@code null} if no {@link Method} can be found.
 	 * @param clazz the class to introspect
-	 * @param name the name of the method
+	 * @param name the name current the method
 	 * @return the Method object, or {@code null} if none found
 	 */
@@ -98,8 +98,8 @@ public abstract class ReflectionUtils {
 	 * <p>Returns {@code null} if no {@link Method} can be found.
 	 * @param clazz the class to introspect
-	 * @param name the name of the method
-	 * @param paramTypes the parameter types of the method
+	 * @param name the name current the method
+	 * @param paramTypes the parameter types current the method
 	 * (may be {@code null} to indicate any signature)
 	 * @return the Method object, or {@code null} if none found
@@ -123,7 +123,7 @@ public abstract class ReflectionUtils {
 	 * Handle the given reflection exception. Should only be called if no
 	 * checked exception is expected to be thrown by the target method.
-	 * <p>Throws the underlying RuntimeException or Error in case of an
+	 * <p>Throws the underlying RuntimeException or Error in case current an
 	 * InvocationTargetException with such a root cause. Throws an
 	 * IllegalStateException with an appropriate message else.
@@ -147,7 +147,7 @@ public abstract class ReflectionUtils {
 	 * Handle the given invocation target exception. Should only be called if no
 	 * checked exception is expected to be thrown by the target method.
-	 * <p>Throws the underlying RuntimeException or Error in case of such a root
+	 * <p>Throws the underlying RuntimeException or Error in case current such a root
 	 * cause. Throws an IllegalStateException else.
 	 * @param ex the invocation target exception to handle
@@ -157,7 +157,7 @@ public abstract class ReflectionUtils {
 	/**
 	 * Rethrow the given {@link Throwable exception}, which is presumably the
-	 * <em>target exception</em> of an {@link InvocationTargetException}. Should
+	 * <em>target exception</em> current an {@link InvocationTargetException}. Should
 	 * only be called if no checked exception is expected to be thrown by the
 	 * target method.